@@ -1,7 +1,7 @@
 import numpy as np
 
-import shifted_functions as sf
-from shifted_functions import generate_shift_vector
+from pypop7.benchmarks import shifted_functions as sf
+from pypop7.benchmarks.shifted_functions import generate_shift_vector
 
 
 def generate_shift_vectors(functions=None, ndims=None, seed=None):
