@@ -1,8 +1,8 @@
 from unittest import TestCase
 import numpy as np
 
-import base_functions
-from utils import _generate_xyz, plot_contour
+from pypop7.benchmarks import base_functions
+from pypop7.benchmarks.utils import _generate_xyz, plot_contour
 
 
 class Test(TestCase):
