@@ -2,7 +2,7 @@ import unittest
 import time
 import numpy as np
 
-from benchmarks.base_functions import ellipsoid, rosenbrock, rastrigin
+from pypop7.benchmarks.base_functions import ellipsoid, rosenbrock, rastrigin
 from optimizers.es.saes import SAES as Solver
 
 
